#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_IEEE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_IEEE_HPP_INCLUDED

#include <boost/simd/constant/include/constants/ieee.hpp>

#endif
